@@ -1,5 +1,5 @@
 package MyService::MyEntry;
-use Moose;
+use Any::Moose;
 use Net::Google::DataAPI;
 with 'Net::Google::DataAPI::Role::Entry';
 use XML::Atom::Util qw(textValue);
